@@ -1,29 +1,26 @@
 """The dates module implements classes for representing and
 manipulating several date types.
 
-Classes
--------
-* BaseDate
-* CalendarDateMixin
-* JulianDay
-* GregorianDate
-* HebrewDate
+Contents
+--------
+* :class:`~pyluach.dates.BaseDate`
+* :class:`~pyluach.dates.CalendarDateMixin`
+* :class:`~pyluach.dates.JulianDay`
+* :class:`~pyluach.dates.GregorianDate`
+* :class:`~pyluach.dates.HebrewDate`
 
-Note
-----
+Notes
+-----
 All instances of the classes in this module should be treated as read
 only. No attributes should be changed once they're created.
 """
 
-from __future__ import division
-
 from datetime import date
 from numbers import Number
-
-from pyluach.utils import memoize
+from functools import lru_cache
 
 
-class BaseDate(object):
+class BaseDate:
     """BaseDate is a base class for all date types.
 
     It provides the following arithmetic and comparison operators
@@ -43,7 +40,7 @@ class BaseDate(object):
     date1 >=, <= date2   True if both are True
     ===================  =============================================
 
-    Any child of BaseDate that implements a ``jd`` attribute
+    Any child of BaseDate that implements a `jd` attribute
     representing the Julian Day of that date can be compared to and
     diffed with any other valid date type.
     """
@@ -126,7 +123,7 @@ class BaseDate(object):
         return self + (7 - self.weekday())
 
 
-class CalendarDateMixin(object):
+class CalendarDateMixin:
     """CalendarDateMixin is a mixin for Hebrew and Gregorian dates.
 
     Parameters
@@ -622,8 +619,8 @@ class HebrewDate(BaseDate, CalendarDateMixin):
         HebrewDate
           The current Hebrew date from the computer's timestamp.
 
-        Note
-        ----
+        Notes
+        -----
         This method coverts the Gregorian date from the time stamp to
         a Hebrew date, so if it is after nightfall but before
         midnight you will have to add one day, ie.
@@ -670,13 +667,14 @@ class HebrewDate(BaseDate, CalendarDateMixin):
             return True
         return False
 
+    @staticmethod
+    def _elapsed_months(year):
+        return (235 * year - 234) // 19
+
     @classmethod
-    @memoize(maxlen=100)
+    @lru_cache(maxsize=100)
     def _elapsed_days(cls, year):
-        months_elapsed = (
-                      (235 * ((year-1) // 19)) + (12 * ((year-1) % 19)) +
-                      (7 * ((year-1) % 19) + 1) // 19
-                      )
+        months_elapsed = cls._elapsed_months(year)
         parts_elapsed = 204 + 793*(months_elapsed%1080)
         hours_elapsed = (5 + 12*months_elapsed + 793*(months_elapsed//1080) +
                          parts_elapsed//1080)
